
rm(list = ls())

library(lme4)
library(lmerTest)
library(car)
library(sjPlot)
library(dplyr)
library(MASS)
library(Rmisc)
library(ggplot2)


simple2<-contr.treatment(2)-matrix(rep(1/2, 2), ncol=1)
simple4<-contr.treatment(4)-matrix(rep(1/4, 12), ncol=3)

path<-'G:\\blocknaming\\beh\\'
data<-read.table(paste(path,'all_beh_checkvocal.txt',sep=''),stringsAsFactors = F,head=T)

cleanData <- data%>%filter(acc!=0)%>%filter(rt!=-10000)%>%
  filter(acc==1)%>% filter(rt>300 & rt<1500)%>%
  dplyr::group_by(subject,type,cycle,context) %>% 
  mutate(sd = scale(rt))%>% filter(abs(sd) <= 3)

cleanData[,c('cycle','type','subject','item','context')]<-lapply(cleanData[,c('cycle','type','subject','item','context')],factor)

contrasts(cleanData$type)<-simple2
contrasts(cleanData$context)<-simple2
contrasts(cleanData$cycle)<-simple4

t.fit<-lmer(rt2~type*context+(1+type+context|subject)+(1+context+type|item),data=cleanData,control = lmerControl(optimizer = "bobyqa"))
summary(t.fit)
anova(t.fit)



initial<-cleanData[cleanData$type=='phonology_initial',]
i.fit<-lmer(rt2~cycle*context+(1+context|subject)+(1+context|itemname),data=initial,control = lmerControl(optimizer = "bobyqa"))
summary(i.fit)


distributed<-cleanData[cleanData$type=='phonology_distributed',]
d.fit<-lmer(rt2~context*cycle+(1+context|subject)+(1+context|itemname),data=distributed,control = lmerControl(optimizer = "bobyqa"))
summary(d.fit)


(ds<-summarySEwithin(cleanData,'rt2',withinvars = c('type','cycle','context'),idvar='subject'))

#########################################################################################

heteroComp<-cleanData[cleanData$context=='hete',]

h.fit<-lmer(rt2~type+(1+type|subject)+(1|itemname),data=heteroComp)
summary(h.fit)


#########################################################################################
###################################  descriptive statistics #############################
#########################################################################################
name<-paste("D:\\response time_color_violin_box",".jpeg",sep='')
jpeg(name,width=1800*1,height=1080*1,res=300*1) #鐠侯垵鍔欓崡銈呯箹閼存鍔夐懘銏ｅ妳300
opar<-par(mfrow=c(1,1),mar=c(1,1,1,1),cex.main=0.5,family='Times New Roman') #

p<-ggplot(cleanData,aes(type,rt2,fill = factor(context)))
p+geom_violin()+
  geom_boxplot(width = 0.07,position = position_dodge(width = 0.9),color='grey')+
  coord_cartesian(ylim=c(200,1000))+
  scale_fill_manual(name = "Context", values=c('#003049','#D62828'),labels = c("Heterogeneous", "Homogeneous"))+
  ylab("Response Time (ms)")+xlab("Position of overlap")+
  scale_x_discrete(labels=c('phonology_distributed'='Distributed','phonology_initial'='Initial'))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background=element_blank(), axis.line = element_line(colour = "black"),
        axis.title.x = element_text(size=12,vjust=-0.8),text = element_text(size = 12))
dev.off()

##########################################################################################################


GeomSplitViolin <- ggproto("GeomSplitViolin", GeomViolin, draw_group = function(self, data, ..., draw_quantiles = NULL){
  data <- transform(data, xminv = x - violinwidth * (x - xmin), xmaxv = x + violinwidth * (xmax - x))
  grp <- data[1,'group']
  newdata <- plyr::arrange(transform(data, x = if(grp%%2==1) xminv else xmaxv), if(grp%%2==1) y else -y)
  newdata <- rbind(newdata[1, ], newdata, newdata[nrow(newdata), ], newdata[1, ])
  newdata[c(1,nrow(newdata)-1,nrow(newdata)), 'x'] <- round(newdata[1, 'x']) 
  if (length(draw_quantiles) > 0 & !scales::zero_range(range(data$y))) {
    stopifnot(all(draw_quantiles >= 0), all(draw_quantiles <= 
                                              1))
    quantiles <- ggplot2:::create_quantile_segment_frame(data, draw_quantiles)
    aesthetics <- data[rep(1, nrow(quantiles)), setdiff(names(data), c("x", "y")), drop = FALSE]
    aesthetics$alpha <- rep(1, nrow(quantiles))
    both <- cbind(quantiles, aesthetics)
    quantile_grob <- GeomPath$draw_panel(both, ...)
    ggplot2:::ggname("geom_split_violin", grid::grobTree(GeomPolygon$draw_panel(newdata, ...), quantile_grob))
  }
  else {
    ggplot2:::ggname("geom_split_violin", GeomPolygon$draw_panel(newdata, ...))
  }
})



geom_split_violin <- function (mapping = NULL, data = NULL, stat = "ydensity", position = "identity", ..., draw_quantiles = NULL, trim = TRUE, scale = "area", na.rm = FALSE, show.legend = NA, inherit.aes = TRUE) {
  layer(data = data, mapping = mapping, stat = stat, geom = GeomSplitViolin, position = position, show.legend = show.legend, inherit.aes = inherit.aes, params = list(trim = trim, scale = scale, draw_quantiles = draw_quantiles, na.rm = na.rm, ...))
}